@@ -41,20 +41,20 @@ mi.continuous <- function ( formula, data = NULL, start = NULL,
   bglm.imp    <- bayesglm( formula = formula, data = data, family = gaussian, 
                             n.iter = n.iter, start = start, 
                             drop.unused.levels = FALSE, Warning=FALSE,... )
-
-####get right design matrix#
-  tt <- terms(bglm.imp)
-  Terms <- delete.response(tt)
-  m <- model.frame(Terms, data=data,  xlev = bglm.imp$xlevels)
-  X <- as.matrix(model.matrix(Terms, m, contrasts.arg = bglm.imp$contrasts))
-############################
   determ.pred <- predict(bglm.imp, newdata = data, type = "response" )
+
   if(n.mis>0){
     if(draw.from.beta){
+    ####get right design matrix#
+      tt <- terms(bglm.imp)
+      Terms <- delete.response(tt)
+      mf <- model.frame(Terms, data=data,  xlev = bglm.imp$xlevels)
+      mf <- as.matrix(model.matrix(Terms, mf, contrasts.arg = bglm.imp$contrasts))
+    ############################
       sim.bglm.imp  <- sim(bglm.imp,1)
       sim.coef <- sim.bglm.imp$coef
       sim.sigma <- sim.bglm.imp$sigma
-      random.pred <- rnorm(n.mis, tcrossprod(X[mis,,drop=FALSE], sim.coef), sim.sigma)
+      random.pred <- rnorm(n.mis, tcrossprod(mf[mis,,drop=FALSE], sim.coef), sim.sigma)
     }
     else{
       random.pred <- rnorm(n.mis, determ.pred[mis], sigma.hat(bglm.imp))
